==> pypi_jump_to-0.1.0.tar.gz: pypi_jump_to-0.1.0/README.md <==
<div align="center">
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="logo" src="https://github.com/volopivoshenko/pypi-jump-to/blob/main/docs/static/assets/logo.svg?raw=True" height=200>
    </a>
</div>

<p align="center">
    <a href="https://opensource.org/licenses/MIT">
        <img alt="license" src="https://img.shields.io/pypi/l/pypi-jump-to?logo=opensourceinitiative">
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="python" src="https://img.shields.io/pypi/pyversions/pypi-jump-to?logo=python">
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="pypi" src="https://img.shields.io/pypi/v/pypi-jump-to?logo=pypi">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/releases">
        <img alt="release" src="https://img.shields.io/github/v/release/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://numpydoc.readthedocs.io/en/latest/format.html">
        <img alt="numpydoc" src="https://img.shields.io/badge/docstrings-numpy-1f425f.svg?logo=numpy">
    </a>
</p>

<p align="center">
    <a href="https://github.com/psf/black">
        <img alt="black" src="https://img.shields.io/badge/code_style-black-black.svg?logo=windowsterminal">
    </a>
    <a href="https://pycqa.github.io/isort/index.html">
        <img alt="isort" src="https://img.shields.io/badge/imports-isort-black.svg?logo=windowsterminal">
    </a>
    <a href="https://beta.ruff.rs/docs/">
        <img alt="ruff" src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json">
    </a>
    <a href="https://mypy.readthedocs.io/en/stable/index.html">
        <img alt="mypy" src="https://img.shields.io/badge/mypy-checked-success.svg?logo=python">
    </a>
    <a href="https://github.com/semantic-release/semantic-release">
        <img alt="semantic_release" src="https://img.shields.io/badge/semantic_release-angular-e10079?logo=semantic-release">
    </a>
</p>

<p align="center">
    <a href="https://github.com/dependabot">
        <img alt="dependabot" src="https://img.shields.io/badge/dependabot-enable-success?logo=Dependabot">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/actions/workflows/ci.yaml">
        <img alt="CI" src="https://img.shields.io/github/actions/workflow/status/volopivoshenko/pypi-jump-to/ci.yaml?label=CI&logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/actions/workflows/cd.yaml">
        <img alt="CD" src="https://img.shields.io/github/actions/workflow/status/volopivoshenko/pypi-jump-to/cd.yaml?label=CD&logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/actions/workflows/codeql.yaml">
        <img alt="CodeQL" src="https://img.shields.io/github/actions/workflow/status/volopivoshenko/pypi-jump-to/codeql.yaml?label=CodeQL&logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/actions/workflows/dependency-review.yaml">
        <img alt="Dependency Review" src="https://img.shields.io/github/actions/workflow/status/volopivoshenko/pypi-jump-to/dependency-review.yaml?label=Dependency%20Review&logo=github">
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="wheel" src="https://img.shields.io/pypi/wheel/pypi-jump-to?logo=pypi">
    </a>
</p>

<p align="center">
    <a href="https://codecov.io/gh/volopivoshenko/pypi-jump-to">
        <img alt="coverage" src="https://img.shields.io/codecov/c/gh/volopivoshenko/pypi-jump-to?logo=codecov&token=yyck08xfTN"/>
    </a>
    <a href="https://codeclimate.com/github/volopivoshenko/pypi-jump-to/maintainability">
        <img alt="codeclimate" src="https://img.shields.io/codeclimate/maintainability/volopivoshenko/pypi-jump-to?logo=codeclimate">
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="downloads" src="https://img.shields.io/pypi/dm/pypi-jump-to?logo=pypi">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/">
        <img alt="stars" src="https://img.shields.io/github/stars/volopivoshenko/pypi-jump-to?logo=github">
    </a>
</p>

<p align="center">
    <a href="https://github.com/volopivoshenko/pypi-jump-to/issues">
        <img alt="issues" src="https://img.shields.io/github/issues/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/issues">
        <img alt="issues" src="https://img.shields.io/github/issues-closed/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/pulls">
        <img alt="pr" src="https://img.shields.io/github/issues-pr/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/pulls">
        <img alt="pr" src="https://img.shields.io/github/issues-pr-closed/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/graphs/contributors">
        <img alt="contributors" src="https://img.shields.io/github/contributors/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/commits/main">
        <img alt="commit" src="https://img.shields.io/github/last-commit/volopivoshenko/pypi-jump-to?logo=github">
    </a>
</p>

<p align="center">
    <a href="https://www.buymeacoffee.com/volopivoshenko" target="_blank">
        <img alt="buymeacoffee" src="https://img.shields.io/badge/buy_me_-a_coffee-ff6964?logo=buymeacoffee">
    </a>
    <a href="https://stand-with-ukraine.pp.ua/">
        <img alt="standwithukraine" src="https://img.shields.io/badge/Support-Ukraine-FFD500?style=flat&labelColor=005BBB">
    </a>
    <a href="https://stand-with-ukraine.pp.ua">
        <img alt="standwithukraine" src="https://img.shields.io/badge/made_in-Ukraine-ffd700.svg?labelColor=0057b7">
    </a>
</p>

==> pypi_jump_to-0.2.0.tar.gz: pypi_jump_to-0.2.0/README.md <==
<div align="center">
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="logo" src="https://github.com/volopivoshenko/pypi-jump-to/blob/main/docs/static/assets/logo.svg?raw=True" height=200>
    </a>
</div>

<p align="center">
    <a href="https://opensource.org/licenses/MIT">
        <img alt="license" src="https://img.shields.io/pypi/l/pypi-jump-to?logo=opensourceinitiative">
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="python" src="https://img.shields.io/pypi/pyversions/pypi-jump-to?logo=python">
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="pypi" src="https://img.shields.io/pypi/v/pypi-jump-to?logo=pypi">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/releases">
        <img alt="release" src="https://img.shields.io/github/v/release/volopivoshenko/pypi-jump-to?logo=github">
    </a>
</p>

<p align="center">
    <a href="https://github.com/psf/black">
        <img alt="black" src="https://img.shields.io/badge/code_style-black-black.svg?logo=windowsterminal">
    </a>
    <a href="https://pycqa.github.io/isort/index.html">
        <img alt="isort" src="https://img.shields.io/badge/imports-isort-black.svg?logo=windowsterminal">
    </a>
    <a href="https://beta.ruff.rs/docs/">
        <img alt="ruff" src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json">
    </a>
    <a href="https://mypy.readthedocs.io/en/stable/index.html">
        <img alt="mypy" src="https://img.shields.io/badge/mypy-checked-success.svg?logo=python">
    </a>
    <a href="https://github.com/semantic-release/semantic-release">
        <img alt="semantic_release" src="https://img.shields.io/badge/semantic_release-angular-e10079?logo=semantic-release">
    </a>
    <a href="https://python-poetry.org">
        <img alt="poetry" src="https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json">
    </a>
    <a href="https://numpydoc.readthedocs.io/en/latest/format.html">
        <img alt="numpydoc" src="https://img.shields.io/badge/docstrings-numpy-1f425f.svg?logo=numpy">
    </a>
</p>

<p align="center">
    <a href="https://github.com/dependabot">
        <img alt="dependabot" src="https://img.shields.io/badge/dependabot-enable-success?logo=Dependabot">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/actions/workflows/ci.yaml">
        <img alt="CI" src="https://img.shields.io/github/actions/workflow/status/volopivoshenko/pypi-jump-to/ci.yaml?label=CI&logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/actions/workflows/cd.yaml">
        <img alt="CD" src="https://img.shields.io/github/actions/workflow/status/volopivoshenko/pypi-jump-to/cd.yaml?label=CD&logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/actions/workflows/dependency-review.yaml">
        <img alt="Dependency Review" src="https://img.shields.io/github/actions/workflow/status/volopivoshenko/pypi-jump-to/dependency-review.yaml?label=Dependency%20Review&logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/blob/main/.pre-commit-config.yaml">
        <img alt="hooks" src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit">
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="wheel" src="https://img.shields.io/pypi/wheel/pypi-jump-to?logo=pypi">
    </a>
</p>

<p align="center">
    <a href="https://codecov.io/gh/volopivoshenko/pypi-jump-to">
        <img alt="coverage" src="https://img.shields.io/codecov/c/gh/volopivoshenko/pypi-jump-to?logo=codecov&token=yyck08xfTN"/>
    </a>
    <a href="https://codeclimate.com/github/volopivoshenko/pypi-jump-to/maintainability">
        <img alt="codeclimate" src="https://api.codeclimate.com/v1/badges/de75fe63b6973fb5bd6a/maintainability"/>
    </a>
    <a href="https://pypi.org/project/pypi-jump-to">
        <img alt="downloads" src="https://img.shields.io/pypi/dm/pypi-jump-to?logo=pypi">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/">
        <img alt="stars" src="https://img.shields.io/github/stars/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://wakatime.com/badge/user/9862508c-0a86-427a-929c-46186f2d191a/project/36344bbb-7f11-4dcd-a36d-e54c81551119">
        <img alt="wakatime" src="https://wakatime.com/badge/user/9862508c-0a86-427a-929c-46186f2d191a/project/36344bbb-7f11-4dcd-a36d-e54c81551119.svg">
    </a>
</p>

<p align="center">
    <a href="https://github.com/volopivoshenko/pypi-jump-to/issues">
        <img alt="issues" src="https://img.shields.io/github/issues/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/issues">
        <img alt="issues" src="https://img.shields.io/github/issues-closed/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/pulls">
        <img alt="pr" src="https://img.shields.io/github/issues-pr/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/pulls">
        <img alt="pr" src="https://img.shields.io/github/issues-pr-closed/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/graphs/contributors">
        <img alt="contributors" src="https://img.shields.io/github/contributors/volopivoshenko/pypi-jump-to?logo=github">
    </a>
    <a href="https://github.com/volopivoshenko/pypi-jump-to/commits/main">
        <img alt="commit" src="https://img.shields.io/github/last-commit/volopivoshenko/pypi-jump-to?logo=github">
    </a>
</p>

<p align="center">
    <a href="https://www.buymeacoffee.com/volopivoshenko" target="_blank">
        <img alt="buymeacoffee" src="https://img.shields.io/badge/buy_me_-a_coffee-ff6964?logo=buymeacoffee">
    </a>
    <a href="https://stand-with-ukraine.pp.ua/">
        <img alt="standwithukraine" src="https://img.shields.io/badge/Support-Ukraine-FFD500?style=flat&labelColor=005BBB">
    </a>
    <a href="https://stand-with-ukraine.pp.ua">
        <img alt="standwithukraine" src="https://img.shields.io/badge/made_in-Ukraine-ffd700.svg?labelColor=0057b7">
    </a>
</p>

## ✨ Overview

## ⚙️ Installation

## 👩🏻‍💻 Usage
